Package: littler
Type: Package
Title: R at the Command-Line via 'r'
Version: 0.3.23
Date: 2026-04-12
Authors@R: c(person("Dirk", "Eddelbuettel", role = c("aut", "cre"), email = "edd@debian.org",
                    comment = c(ORCID = "0000-0001-6419-907X")),
             person("Jeff", "Horner", role = "aut",
                    comment = "(2006-2008)"))
Description: A scripting and command-line front-end
 is provided by 'r' (aka 'littler') as a lightweight binary wrapper around
 the GNU R language and environment for statistical computing and graphics.
 While R can be used in batch mode, the r binary adds full support for
 both 'shebang'-style scripting (i.e. using a  hash-mark-exclamation-path
 expression as the first line in scripts) as well as command-line use in
 standard Unix pipelines. In other words, r provides the R language without
 the environment.
URL: https://github.com/eddelbuettel/littler,
        https://dirk.eddelbuettel.com/code/littler.html,
        https://eddelbuettel.github.io/littler/
BugReports: https://github.com/eddelbuettel/littler/issues
License: GPL (>= 2)
OS_type: unix
SystemRequirements: libR
Suggests: simplermarkdown, docopt, rcmdcheck, whoami
VignetteBuilder: simplermarkdown
RoxygenNote: 5.0.1
NeedsCompilation: yes
Packaged: 2026-04-12 14:00:54 UTC; edd
Author: Dirk Eddelbuettel [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6419-907X>),
  Jeff Horner [aut] ((2006-2008))
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-04-12 14:10:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-15 04:55:41 UTC; unix
